Skip to contents

Create a GitHub Action workflow that builds a pkgdown site from your package and deploys it to the gh-pages branch.

Usage

rog_actions_pkgdown_branch(pkg = ".", overwrite = TRUE)

Arguments

pkg

Path to the package.

overwrite

Whether to overwrite the workflow if it already exists.

Value

This function is called for its side effects and returns NULL invisibly.

See also

usethis's usethis::use_github_action() for creating workflows from other templates.

Site setup helpers: rog_add_template_pkgdown(), rog_build()