Skip to contents

A wrapper around pkgdown's pkgdown::build_site().

Usage

rog_build(pkg = ".", ...)

Arguments

pkg

Path to the package.

...

Arguments passed on to rog_logo, pkgdown::build_site

overwrite

Should the current logo be overwritten? When TRUE, it runs usethis's usethis::use_logo().

favicons

Should favicons be created with pkgdown's pkgdown::build_favicons()?

p_x

x position for package name

p_y

y position for package name

p_size

font size for package name

examples

Run examples?

preview

If TRUE, or is.na(preview) && interactive(), will preview freshly generated section in browser.

new_process

If TRUE, will run build_site() in a separate process. This enhances reproducibility by ensuring nothing that you have loaded in the current process affects the build process.

install

If TRUE, will install the package in a temporary library so it is available for vignettes.

Value

The function is called for its side effects and returns invisible(NULL).

Details

This function also calls rog_add_template_pkgdown() and rog_logo().