Deploy a pkgdown site with GitHub Actions
Source:R/rog-actions-pkgdown-branch.R
rog_actions_pkgdown_branch.RdCreate a GitHub Action workflow that builds a pkgdown site from
your package and deploys it to the gh-pages branch.
Value
This function is called for its side effects and returns
NULL invisibly.
See also
usethis's usethis::use_github_action() for creating
workflows from other templates.
Site setup helpers:
rog_add_template_pkgdown(),
rog_build()