Skip to contents

Create a GitHub Action workflow that builds a pkgdown site from your package and deploys it to the gh-pages branch.

Usage

rog_actions_pkgdown_branch(pkg = ".", overwrite = TRUE)

Arguments

pkg

Path to package.

overwrite

Overwrite the workflow if it already exists.

Value

The function is called for its side effects and returns invisible(NULL).

See also