Skip to contents

Add the rOpenGov template configuration to your _pkgdown.yml. If no configuration file exists, create one at pkgdown/_pkgdown.yml. Also add the corresponding paths to .Rbuildignore.

Usage

rog_add_template_pkgdown()

Value

The function is called for its side effects and returns invisible(NULL).

Details

The function also adds these package URLs to _pkgdown.yml and DESCRIPTION if they are not already present:

  • https://ropengov.github.io/pkgname/

  • https://github.com/rOpenGov/pkgname

Examples

# \dontrun{
rog_add_template_pkgdown()
#> Error: No DESCRIPTION file found.
# }