A wrapper around pkgdown's pkgdown::build_site().
Arguments
- pkg
Path to the package.
- ...
Arguments passed on to
rog_logo,pkgdown::build_siteoverwriteShould the current logo be overwritten? When
TRUE, it runs usethis'susethis::use_logo().faviconsShould favicons be created with pkgdown's
pkgdown::build_favicons()?p_xx position for package name
p_yy position for package name
p_sizefont size for package name
examplesRun examples?
previewIf
TRUE, oris.na(preview) && interactive(), will preview freshly generated section in browser.new_processIf
TRUE, will runbuild_site()in a separate process. This enhances reproducibility by ensuring nothing that you have loaded in the current process affects the build process.installIf
TRUE, will install the package in a temporary library so it is available for vignettes.
Details
This function also calls rog_add_template_pkgdown() and rog_logo().
See also
pkgdown's pkgdown::build_site().
Site setup helpers:
rog_actions_pkgdown_branch(),
rog_add_template_pkgdown()